==> openjdk-src-11.0.1.u13-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_es_419.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_es_419 extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "011", "\u00c1frica del Oeste" },
            { "014", "\u00c1frica del Este" },
            { "015", "\u00c1frica del Norte" },
            { "018", "\u00c1frica del Sur" },
            { "030", "Asia del Este" },
            { "034", "Asia del Sur" },
            { "035", "Asia sudoriental" },
            { "039", "Europa del Sur" },
            { "057", "regi\u00f3n de Micronesia" },
            { "145", "Asia del Oeste" },
            { "151", "Europa del Este" },
            { "154", "Europa del Norte" },
            { "155", "Europa del Oeste" },
            { "AC", "Isla Ascensi\u00f3n" },
            { "BA", "Bosnia-Herzegovina" },
            { "CI", "Costa de Marfil" },
            { "EZ", "Eurozona" },
            { "GG", "Guernesey" },
            { "IC", "Islas Canarias" },
            { "QO", "Islas Ultramarinas" },
            { "TA", "Trist\u00e1n da Cunha" },
            { "TL", "Timor Oriental" },
            { "UM", "Islas Ultramarinas de EE.UU." },
            { "VI", "Islas V\u00edrgenes de los Estados Unidos" },
            { "eu", "vasco" },
            { "gu", "gujarati" },
            { "ht", "haitiano" },
            { "lo", "laosiano" },
            { "nr", "ndebele del sur" },
            { "rm", "retorrom\u00e1nico" },
            { "st", "sesotho del sur" },
            { "sw", "swahili" },
            { "ace", "achen\u00e9s" },
            { "ady", "adigeo" },
            { "alt", "alt\u00e1i del sur" },
            { "arp", "arapaj\u00f3" },
            { "ars", "\u00e1rabe de N\u00e9yed" },
            { "bla", "siksik\u00e1" },
            { "goh", "alem\u00e1n de la alta edad antigua" },
            { "grc", "griego cl\u00e1sico" },
            { "kbd", "cabardiano" },
            { "prg", "prusiano antiguo" },
            { "shu", "\u00e1rabe (Chad)" },
            { "sma", "sami del sur" },
            { "syr", "sir\u00edaco" },
            { "tet", "tetun" },
            { "tzm", "tamazight del Marruecos Central" },
            { "wal", "walamo" },
            { "wuu", "wu" },
            { "zun", "zuni" },
            { "Hanb", "han con bopomofo" },
            { "Hrkt", "katakana o hiragana" },
            { "Laoo", "lao" },
            { "Latn", "lat\u00edn" },
            { "Mlym", "malayalam" },
            { "sw_CD", "swahili (Congo)" },
            { "key.lb", "salto de l\u00ednea" },
            { "key.ms", "sm" },
            { "type.co.eor", "reglas de orden europeas" },
            { "type.nu.tirh", "d\u00edgitos en tirh" },
            { "type.nu.wara", "d\u00edgitos en Warang Citi" },
            { "type.lb.loose", "salto de l\u00ednea flexible" },
            { "type.co.compat", "orden anterior, para compatibilidad" },
            { "type.lb.strict", "salto de l\u00ednea estricto" },
            { "type.ms.metric", "Sistema M\u00e9trico de Unidades" },
            { "type.ms.uksystem", "sistema ingl\u00e9s" },
            { "type.ms.ussystem", "Sistema Anglosaj\u00f3n de Unidades" },
            { "type.co.phonebook", "orden de agenda telef\u00f3nica" },
            { "type.nu.traditional", "n\u00fameros traducionales" },
            { "type.ca.islamic-umalqura", "islamic-umalqura" },
        };
        return data;
    }
}

==> openjdk-src-15.0.2.u7-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_es_419.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_es_419 extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "011", "\u00c1frica del Oeste" },
            { "014", "\u00c1frica del Este" },
            { "015", "\u00c1frica del Norte" },
            { "018", "\u00c1frica del Sur" },
            { "030", "Asia del Este" },
            { "034", "Asia del Sur" },
            { "035", "Asia sudoriental" },
            { "039", "Europa del Sur" },
            { "145", "Asia del Oeste" },
            { "151", "Europa del Este" },
            { "154", "Europa del Norte" },
            { "155", "Europa del Oeste" },
            { "AC", "Isla Ascensi\u00f3n" },
            { "BA", "Bosnia-Herzegovina" },
            { "CG", "Rep\u00fablica del Congo" },
            { "CI", "Costa de Marfil" },
            { "EZ", "Eurozona" },
            { "GG", "Guernesey" },
            { "IC", "Islas Canarias" },
            { "QO", "Islas Ultramarinas" },
            { "TA", "Trist\u00e1n da Cunha" },
            { "UM", "Islas Ultramarinas de EE.UU." },
            { "eu", "vasco" },
            { "gu", "gujarati" },
            { "ht", "haitiano" },
            { "lo", "laosiano" },
            { "nr", "ndebele del sur" },
            { "pa", "panyab\u00ed" },
            { "rm", "retorrom\u00e1nico" },
            { "st", "sesotho del sur" },
            { "sw", "swahili" },
            { "ace", "achen\u00e9s" },
            { "ady", "adigeo" },
            { "alt", "alt\u00e1i del sur" },
            { "arp", "arapaj\u00f3" },
            { "ars", "\u00e1rabe de N\u00e9yed" },
            { "bla", "siksik\u00e1" },
            { "goh", "alem\u00e1n de la alta edad antigua" },
            { "grc", "griego cl\u00e1sico" },
            { "kbd", "cabardiano" },
            { "krc", "karach\u00e1i-b\u00e1lkaro" },
            { "nso", "sesotho del norte" },
            { "prg", "prusiano antiguo" },
            { "shu", "\u00e1rabe (Chad)" },
            { "sma", "sami del sur" },
            { "syr", "sir\u00edaco" },
            { "tet", "tetun" },
            { "tyv", "tuvano" },
            { "wal", "walamo" },
            { "wuu", "wu" },
            { "xal", "calmuco" },
            { "zun", "zuni" },
            { "Hanb", "han con bopomofo" },
            { "Hrkt", "katakana o hiragana" },
            { "Laoo", "lao" },
            { "Latn", "lat\u00edn" },
            { "Mlym", "malayalam" },
            { "Olck", "ol chiki" },
            { "sw_CD", "swahili (Congo)" },
            { "type.co.eor", "reglas de orden europeas" },
            { "type.nu.tirh", "d\u00edgitos en tirh" },
            { "type.nu.wara", "d\u00edgitos en Warang Citi" },
            { "type.co.compat", "orden anterior, para compatibilidad" },
            { "type.co.phonebook", "orden de agenda telef\u00f3nica" },
            { "type.nu.traditional", "n\u00fameros traducionales" },
            { "type.ca.islamic-rgsa", "calendario isl\u00e1mico (Arabia Saudita)" },
            { "type.ca.islamic-tbla", "calendario isl\u00e1mico tabular" },
        };
        return data;
    }
}
